@@ -122,6 +122,10 @@ class Question(core_models.SlugModel):
         models.CharField(max_length=255), blank=True, default=list
     )
 
+    default_answer = models.ForeignKey(
+        "Answer", on_delete=models.CASCADE, related_name="+", null=True, blank=True
+    )
+
     @property
     def min_length(self):
         return self.configuration.get("min_length")
@@ -164,6 +168,10 @@ class Question(core_models.SlugModel):
         }
         return empties.get(self.type, None)
 
+    def __repr__(self):
+        base = super().__repr__()
+        return base[:-1] + f", type={self.type})"
+
     class Meta:
         indexes = [GinIndex(fields=["meta"])]
 
@@ -269,27 +277,13 @@ class Document(core_models.UUIDModel):
 
         # copy answers
         for source_answer in self.answers.all():
-            new_answer = new_document.answers.create(
-                question=source_answer.question,
-                value=source_answer.value,
-                meta=dict(source_answer.meta),
-                date=source_answer.date,
-            )
-
-            if source_answer.question.type == Question.TYPE_FILE:
-                new_answer.file = source_answer.file.copy()
-                new_answer.save()
-
-            # TableAnswer: copy AnswerDocument too
-            for answer_doc in AnswerDocument.objects.filter(answer=source_answer):
-                new_doc = answer_doc.document.copy(family=family)
-
-                AnswerDocument.objects.create(
-                    answer=new_answer, document=new_doc, sort=answer_doc.sort
-                )
+            source_answer.copy(document_family=family, to_document=new_document)
 
         return new_document
 
+    def __repr__(self):
+        return f"Document(form={self.form!r})"
+
     class Meta:
         indexes = [GinIndex(fields=["meta"])]
 
@@ -317,7 +311,11 @@ class Answer(core_models.BaseModel):
     value = JSONField(null=True, blank=True)
     meta = JSONField(default=dict)
     document = models.ForeignKey(
-        Document, on_delete=models.CASCADE, related_name="answers"
+        Document,
+        on_delete=models.CASCADE,
+        related_name="answers",
+        null=True,
+        blank=True,
     )
     documents = models.ManyToManyField(
         Document, through="AnswerDocument", related_name="+"
@@ -341,6 +339,57 @@ class Answer(core_models.BaseModel):
             self.file.delete()
         super().delete(args, kwargs)
 
+    def create_answer_documents(self, documents):
+        family = self.document.family
+        document_ids = [document.pk for document in documents]
+
+        for sort, document_id in enumerate(reversed(document_ids), start=1):
+            ans_doc, created = AnswerDocument.objects.get_or_create(
+                answer=self, document_id=document_id, defaults={"sort": sort}
+            )
+            if not created and ans_doc.sort != sort:
+                ans_doc.sort = sort
+                ans_doc.save()
+            if created:
+                # Already-existing documents are already in the family,
+                # so we're updating only the newly attached rows
+                ans_doc.document.set_family(family)
+
+    def unlink_unused_rows(self, docs_to_keep):
+        existing = AnswerDocument.objects.filter(answer=self).exclude(
+            document__in=docs_to_keep
+        )
+        for ans_doc in list(existing.select_related("document")):
+            # Set document to be its own family
+            # TODO: Can/should we delete the detached documents?
+            ans_doc.document.set_family(ans_doc.document)
+            ans_doc.delete()
+
+    def copy(self, document_family=None, to_document=None):
+        new_answer = type(self).objects.create(
+            question=self.question,
+            value=self.value,
+            meta=dict(self.meta),
+            date=self.date,
+            document=to_document,
+        )
+
+        if self.question.type == Question.TYPE_FILE:
+            new_answer.file = self.file.copy()
+            new_answer.save()
+
+        # TableAnswer: copy AnswerDocument too
+        for answer_doc in AnswerDocument.objects.filter(answer=self):
+            new_doc = answer_doc.document.copy(family=document_family)
+
+            AnswerDocument.objects.create(
+                answer=new_answer, document=new_doc, sort=answer_doc.sort
+            )
+        return new_answer
+
+    def __repr__(self):
+        return f"Answer(document={self.document!r}, question={self.question!r}, value={self.value!r})"
+
     class Meta:
         # a question may only be answerd once per document
         unique_together = ("document", "question")
