@@ -1,4 +1,5 @@
 import pytest
+from django.utils.dateparse import parse_date
 from graphql_relay import to_global_id
 
 from ...caluma_core.relay import extract_global_id
@@ -6,7 +7,7 @@ from ...caluma_core.tests import extract_serializer_input_fields
 from ...caluma_core.visibilities import BaseVisibility, filter_queryset_for
 from ...caluma_form.models import Answer, Document, Question
 from ...caluma_form.schema import Document as DocumentNodeType
-from .. import serializers
+from .. import api, serializers
 
 
 @pytest.mark.parametrize(
@@ -346,8 +347,17 @@ def test_query_all_documents_filter_answers_by_questions(
     assert set(expect_data) == set(result_lengths)
 
 
+@pytest.mark.parametrize("use_python_api", [True, False])
 @pytest.mark.parametrize("update", [True, False])
-def test_save_document(db, document, schema_executor, update):
+def test_save_document(
+    db,
+    document,
+    schema_executor,
+    form_question_factory,
+    answer_factory,
+    update,
+    use_python_api,
+):
     query = """
         mutation SaveDocument($input: SaveDocumentInput!) {
           saveDocument(input: $input) {
@@ -356,35 +366,80 @@ def test_save_document(db, document, schema_executor, update):
                   slug
                 }
                 id
+                answers {
+                  edges {
+                    node {
+                      ... on StringAnswer {
+                        value
+                      }
+                    }
+                  }
+                }
             }
             clientMutationId
           }
         }
     """
 
+    form_question = form_question_factory(
+        question__type=Question.TYPE_TEXT, form=document.form
+    )
+    answer = answer_factory(question=form_question.question, value="foo")
+    form_question.question.default_answer = answer
+    form_question.question.save()
+
     inp = {
         "input": extract_serializer_input_fields(
             serializers.DocumentSerializer, document
         )
     }
 
-    if not update:
-        # not update = create = we don't pass the ID
-        del inp["input"]["id"]
+    if not use_python_api:
+        if not update:
+            # not update = create = we don't pass the ID
+            del inp["input"]["id"]
 
-    result = schema_executor(query, variable_values=inp)
+        result = schema_executor(query, variable_values=inp)
 
-    assert not result.errors
-    assert result.data["saveDocument"]["document"]["form"]["slug"] == document.form.slug
+        assert not result.errors
+        assert (
+            result.data["saveDocument"]["document"]["form"]["slug"]
+            == document.form.slug
+        )
 
-    same_id = extract_global_id(result.data["saveDocument"]["document"]["id"]) == str(
-        document.id
-    )
+        same_id = extract_global_id(
+            result.data["saveDocument"]["document"]["id"]
+        ) == str(document.id)
 
-    # if updating, the resulting document must be the same
-    assert same_id == update
+        # if updating, the resulting document must be the same
+        assert same_id == update
+
+        assert (
+            len(result.data["saveDocument"]["document"]["answers"]["edges"]) == 0
+            if update
+            else 1
+        )
+        if not update:
+            assert (
+                result.data["saveDocument"]["document"]["answers"]["edges"][0]["node"][
+                    "value"
+                ]
+                == "foo"
+            )
+    else:
+        doc = (
+            api.save_document(document.form, document=document)
+            if update
+            else api.save_document(document.form)
+        )
+        assert (doc.pk == document.pk) == update
+
+        assert doc.answers.count() == 0 if update else 1
+        if not update:
+            assert doc.answers.first().value == "foo"
 
 
+@pytest.mark.parametrize("use_python_api", [True, False])  # noqa:C901
 @pytest.mark.parametrize("delete_answer", [True, False])
 @pytest.mark.parametrize("option__slug", ["option-slug"])
 @pytest.mark.parametrize(
@@ -661,6 +716,8 @@ def test_save_document_answer(
     delete_answer,
     minio_mock,
     data_source_settings,
+    use_python_api,
+    admin_user,
 ):
     mutation_func = mutation[0].lower() + mutation[1:]
     query = f"""
@@ -736,15 +793,34 @@ def test_save_document_answer(
         if answer.date == "1900-01-01":
             inp["input"]["value"] = "not a date"
 
+        if use_python_api and success:
+            inp["input"]["value"] = parse_date(inp["input"]["value"])
+
     if delete_answer:
         # delete answer to force create test instead of update
         Answer.objects.filter(pk=answer.pk).delete()
 
-    result = schema_executor(query, variable_values=inp)
+    if not use_python_api:
+        result = schema_executor(query, variable_values=inp)
 
-    assert not bool(result.errors) == success
-    if success:
-        snapshot.assert_match(result.data)
+        assert not bool(result.errors) == success
+
+        if success:
+            snapshot.assert_match(result.data)
+    else:
+        if success:
+            answer = api.save_answer(
+                question, answer.document, user=admin_user, value=inp["input"]["value"]
+            )
+            snapshot.assert_match(answer)
+        else:
+            with pytest.raises(Exception):
+                api.save_answer(
+                    question,
+                    answer.document,
+                    user=admin_user,
+                    value=inp["input"]["value"],
+                )
 
 
 @pytest.mark.parametrize("delete_answer", [True, False])
@@ -839,9 +915,8 @@ def test_save_document_table_answer_invalid_row_form(
             serializers.SaveAnswerSerializer, answer
         )
     }
-    inp["input"]["value"] = [
-        str(document.pk) for document in document_factory.create_batch(1)
-    ]
+    inp["input"]["value"] = [str(document_factory().pk)]
+
     result = schema_executor(query, variable_values=inp)
     assert result.errors
 
@@ -907,6 +982,37 @@ def test_save_document_table_answer_setting_family(
     assert to_be_deleted_table_row.family == to_be_deleted_document.family
 
 
+@pytest.mark.parametrize("default_on_table,value", [(True, 1979), (False, 23)])
+def test_save_document_table_answer_default_answer(
+    db, form_and_document, answer_factory, default_on_table, value
+):
+    form, document, questions_dict, answers_dict = form_and_document(use_table=True)
+
+    table_question = form.questions.filter(type=Question.TYPE_TABLE).first()
+    row_question = table_question.row_form.questions.first()
+
+    row_question_default_answer = answer_factory(question=row_question, value=23)
+    row_question.default_answer = row_question_default_answer
+    row_question.save()
+
+    table_answer = document.answers.filter(question__type=Question.TYPE_TABLE).first()
+
+    if not default_on_table:
+        table_answer.documents.first().answers.first().delete()
+
+    table_question.default_answer = table_answer
+    table_question.save()
+
+    assert Document.objects.filter(form=form).count() == 1
+
+    doc = api.save_document(document.form)
+
+    assert Document.objects.filter(form=form).count() == 2
+
+    assert doc.answers.count() == 1
+    assert doc.answers.first().documents.first().answers.first().value == value
+
+
 @pytest.mark.parametrize("answer__value", [1.1])
 def test_query_answer_node(db, answer, schema_executor):
     global_id = to_global_id("FloatAnswer", answer.pk)
